Learn R Programming

aihuman (version 1.0.0)

CalAPCEipw: Compute APCE using frequentist analysis

Description

Estimate propensity score and use Hajek estimator to compute APCE. See S7 for more details.

Usage

CalAPCEipw(data)

Value

An object of class list with the following elements:

P.D1

An array with dimension (k+1) by (k+2) for quantity P(D(1)=d| R=r), dimension 1 is (k+1) values of D from 0 to k, dimension 2 is (k+2) values of R from 0 to k+1.

P.D0

An array with dimension (k+1) by (k+2) for quantity P(D(0)=d| R=r).

APCE

An array with dimension (k+1) by (k+2) for quantity P(D(1)=d| R=r)-P(D(0)=d| R=r).

P.R

An array with dimension (k+2) for quantity P(R=r) for r from 0 to (k+1).

alpha

An array with estimated alpha.

delta

An array with estimated delta.

Arguments

data

A data.frame or matrix of which columns consists of pre-treatment covariates, a binary treatment (Z), an ordinal decision (D), and an outcome variable (Y). The column names of the latter three should be specified as "Z", "D", and "Y" respectively.

Examples

Run this code
data(synth)
freq_apce <- CalAPCEipw(synth)

Run the code above in your browser using DataLab