Learn R Programming

aihuman (version 1.0.0)

CalDIM: Calculate diff-in-means estimates

Description

Calculate average causal effect based on diff-in-means estimator.

Usage

CalDIM(data)

Value

A data.frame of diff-in-means estimates effect for each value of D and Y.

Arguments

data

A data.frame of which columns includes a binary treatment (Z), an ordinal decision (D), and an outcome variable (Y).

Examples

Run this code
data(synth)
CalDIM(synth)

Run the code above in your browser using DataLab