Learn R Programming

aihuman (version 1.0.0)

TestMonotonicity: Test monotonicity

Description

Test monotonicity using frequentist analysis

Usage

TestMonotonicity(data)

Value

Message indicating whether the monotonicity assumption holds.

Arguments

data

A data.frame or matrix of which columns consists of pre-treatment covariates, a binary treatment (Z), an ordinal decision (D), and an outcome variable (Y). The column names of the latter three should be specified as "Z", "D", and "Y" respectively.

Examples

Run this code
data(synth)
TestMonotonicity(synth)

Run the code above in your browser using DataLab