Learn R Programming

aihuman (version 1.0.0)

compute_stats: Compute Risk (Human+AI v. Human)

Description

Compute the difference in risk between human+AI and human decision makers using difference-in-means estimators.

Usage

compute_stats(Y, D, Z, X = NULL, l01 = 1)

Value

A tibble the following columns:

  • Z_focal: The focal treatment indicator. `1` indicates the treatment group.

  • Z_compare: The comparison treatment indicator. `0` indicates the control group.

  • X: Pretreatment covariate (if provided).

  • loss_diff: The difference in loss between human+AI and human decision

  • loss_diff_se: The standard error of the difference in loss

  • fn_diff: The difference in false negatives between human+AI and human decision

  • fn_diff_se: The standard error of the difference in false negatives

  • fp_diff: The difference in false positives between human+AI and human decision

  • fp_diff_se: The standard error of the difference in false positives

Arguments

Y

An observed outcome (binary: numeric vector of 0 or 1).

D

An observed decision (binary: numeric vector of 0 or 1).

Z

A treatment indicator (binary: numeric vector of 0 or 1).

X

Pretreatment covariate used for subgroup analysis (vector). Must be the same length as Y, D, Z, and A if provided. Default is NULL.

l01

Ratio of the loss between false positives and false negatives

Examples

Run this code
compute_stats(
  Y = NCAdata$Y,
  D = ifelse(NCAdata$D == 0, 0, 1),
  Z = NCAdata$Z,
  X = NULL,
  l01 = 1
)

Run the code above in your browser using DataLab