Implement crossfitting with boosting methods and get predicted values for outcome/decision regression or propensity score models
crossfit(data, include_for_fit, form, ...)A vector of predicted values
A data.frame or matrix to fit on.
Boolean vector for whether or not a unit should be included in fitting (e.g. treated/control).
Formula for outcome regression/propensity score models.
Additional arguments to be passed to gbm function.