Internal function to visualize the difference in risk between AI and human decision makers.
vis_diff_ai(
df,
label.subgroup1 = "Subgroup 1",
label.subgroup2 = "Subgroup 2",
x.order = NULL,
zero.line = TRUE,
arrows = TRUE,
y.min = -Inf,
p.title = NULL,
p.lb = -1,
p.ub = 1,
y.lab = "PSA versus Human",
p.label = c("PSA worse", "PSA better")
)A ggplot object.
A data frame generated by compute_stats_aipw and reshaped.
A label for subgroup1 (character).
A label for subgroup2 (character).
An order for the x-axis (character vector). Default NULL.
A logical indicating whether to include a zero line. Default TRUE.
A logical indicating whether to include arrows. Default TRUE.
A lower bound for the y-axis (numeric). Default -Inf.
A title for the plot (character). Default NULL.
A lower bound for the y-axis (numeric). Default -0.2.
An upper bound for the y-axis (numeric). Default 0.2.
A label for the y-axis (character). Default "PSA versus Human".
A vector of two labels for the annotations (character). Default c("PSA harms", "PSA helps").