Internal function to visualize the difference in risk between human+AI and human decision makers.
vis_diff_human(
df,
label.subgroup1 = "Subgroup 1",
label.subgroup2 = "Subgroup 2",
x.order = NULL,
p.title = NULL,
p.lb = -0.2,
p.ub = 0.2,
y.lab = "Impact of PSA",
p.label = c("PSA harms", "PSA helps")
)A ggplot object.
A data frame generated by compute_stats_aipw and reshaped.
A label for subgroup1 (character).
A label for subgroup2 (character).
An order for the x-axis (character vector). Default NULL.
A title for the plot (character). Default NULL.
A lower bound for the y-axis (numeric). Default -0.2.
An upper bound for the y-axis (numeric). Default 0.2.
A label for the y-axis (character). Default "Impact of PSA".
A vector of two labels for the annotations (character). Default c("PSA harms", "PSA helps").