BootstrapAPCEipw: Bootstrap for estimating variance of APCE
Description
Estimate variance of APCE for frequentist analysis using bootstrap. See S7 for more details.
Usage
BootstrapAPCEipw(data, rep = 1000)
Value
An object of class list with the following elements:
P.D1.boot
An array with dimension rep by (k+1) by (k+2) for quantity P(D(1)=d| R=r), dimension 1 is rep (size of bootstrap), dimension 2 is (k+1) values of D from 0 to k, dimension 3 is (k+2) values of R from 0 to k+1.
P.D0.boot
An array with dimension rep by (k+1) by (k+2) for quantity P(D(0)=d| R=r).
APCE.boot
An array with dimension rep by (k+1) by (k+2) for quantity P(D(1)=d| R=r)-P(D(0)=d| R=r).
P.R.boot
An array with dimension rep by (k+2) for quantity P(R=r) for r from 0 to (k+1).
alpha.boot
An array with estimated alpha for each bootstrap.
delta.boot
An array with estimated delta for each bootstrap.
Arguments
data
A data.frame or matrix of which columns consists of pre-treatment covariates, a binary treatment (Z), an ordinal decision (D), and an outcome variable (Y). The column names of the latter three should be specified as "Z", "D", and "Y" respectively.